@@ -4,17 +4,22 @@ from pathlib import Path
 from python_linters.config_files import RUFF_CONFIG_FILE
 
 
-def create_extended_ruff_toml() -> str:
-    ruff_extension_file = Path("ruff_extension.toml")
+def create_extended_ruff_toml(package_root:str) -> str:
+    ruff_extension_file = Path(f"{package_root}/ruff_extension.toml")
+    ruff_toml_file = Path(f"{package_root}/ruff.toml")
+    if ruff_toml_file.is_file():
+        ruff_config_file = str(ruff_toml_file)
+    else:
+        ruff_config_file = RUFF_CONFIG_FILE
 
+    print(f"using {ruff_config_file=}")
     if ruff_extension_file.is_file():
-        fingerprint = f"{ruff_extension_file.stat().st_size}-{ruff_extension_file.stat().st_mtime}"
-        extended_ruff_toml_file = f"extended_ruff-{fingerprint}.toml"
+        extended_ruff_toml_file = f"{package_root}/extended_ruff.toml"
         if not Path(extended_ruff_toml_file).is_file():
-            print(f"extending {RUFF_CONFIG_FILE} with {ruff_extension_file=}")
+            print(f"extending {ruff_config_file} with {ruff_extension_file=}")
             with Path(extended_ruff_toml_file).open("w", encoding="locale") as f:
                 lines = [
-                    f'extend = "{RUFF_CONFIG_FILE}"',
+                    f'extend = "{ruff_config_file}"',
                     *list(_read_lines(ruff_extension_file)),
                 ]
                 for l in lines:
@@ -22,7 +27,7 @@ def create_extended_ruff_toml() -> str:
         else:
             print(f"using {extended_ruff_toml_file}")
     else:
-        extended_ruff_toml_file = RUFF_CONFIG_FILE
+        extended_ruff_toml_file = ruff_config_file
     return extended_ruff_toml_file
 
 
