@@ -35,17 +35,8 @@ def get_folders_to_be_linted(pyproject_toml: str) -> list[str]:
             .get("python-linters", {})
             .get("folders_to_be_linted", None)
         )
-        if (
-            folders is None
-            and (packages := t.get("tool", {}).get("poetry", {}).get("packages", None))
-            is not None
-        ):
-            folders = [p["include"] for p in packages]
-            if pathlib.Path(f"{pathlib.Path(pyproject_toml).parent}/tests").is_dir():
-                folders += ["tests"]
-
         if folders is None:
-            raise PackagesOrFoldersToBeLintedAreNotProperlyDefined
-    assert len(folders) > 0
+            folders = ["./"]
+            # raise PackagesOrFoldersToBeLintedAreNotProperlyDefined
     print(f"found following {folders=}")
     return folders
