@@ -1,6 +1,7 @@
 # rule_categories copypaste from: https://docs.astral.sh/ruff/rules/
 rule_categories = """
 Pyflakes (F)
+pycodestyle (E, W)
 Warning (W)
 Error (E)
 mccabe (C90)
@@ -11,7 +12,6 @@ pyupgrade (UP)
 flake8-2020 (YTT)
 flake8-annotations (ANN)
 flake8-async (ASYNC)
-flake8-trio (TRIO)
 flake8-bandit (S)
 flake8-blind-except (BLE)
 flake8-boolean-trap (FBT)
@@ -42,7 +42,7 @@ flake8-self (SLF)
 flake8-slots (SLOT)
 flake8-simplify (SIM)
 flake8-tidy-imports (TID)
-flake8-type-checking (TCH)
+flake8-type-checking (TC)
 flake8-gettext (INT)
 flake8-unused-arguments (ARG)
 flake8-use-pathlib (PTH)
@@ -59,9 +59,11 @@ Warning (W)
 tryceratops (TRY)
 flynt (FLY)
 NumPy-specific rules (NPY)
+FastAPI (FAST)
 Airflow (AIR)
 Perflint (PERF)
 refurb (FURB)
+pydoclint (DOC)
 Ruff-specific rules (RUF)
 """
 
